/**
 * Hany Char Convertor
 * Copyright 1999,.. by Peter Hanecak <hanecak@megaloman.sk>.
 *
 * For now it works just as filter reading input from stdin and writing output to stdout.
 *
 * @version 0.4.1
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * See the COPYING file for license information.
 *
 * See COPYING for more information.
 */

#include <cstdlib>
#include <cstring>
#include <iostream>
#include "hcc.h"
#include "ct.h"

int main(int argc, char *argv[]) {
	t_ct	ct;
	char	*ctn = NULL;
	char	*ctfn = CTFN;
	char	buffer[BUFFER_SIZE + 1];
	int	n1;

	// process parameters
	switch (argc) {
		case 3:
			ctfn = (char *)calloc(strlen(argv[2]) + 1, sizeof(char));
			strcpy(ctfn, argv[2]);
		case 2:
			ctn = (char *)calloc(strlen(argv[1]) + 1, sizeof(char));
			strcpy(ctn, argv[1]);
			break;
		default:
			std::cout << Help;
			exit(-1);
	}

	// init conversion table
	#ifdef VERBOSE
	std::cerr << "*** loading conversion table (" << ctfn << ", " << ctn << ") ..." << std::endl;
	#endif
	ct = loadct(ctfn, ctn);
	if (ct == NULL) {
		std::cerr << ErrPrefix << errorMsg;
		if (errorParam != NULL)
			std::cerr << " (" << errorParam << ")" << std::endl;
		std::cerr << std::endl;
		return -1;
	}

	// convertion
	#ifdef VERBOSE
	std::cerr << "*** converting:" << std::endl;
	#endif
	while (!std::cin.eof()) {
		std::cin.read(buffer, BUFFER_SIZE);
		if (std::cin.bad()) {
			std::cerr << ErrPrefix << "unable to read source data" << std::endl;
			return -1;
		}

		for (n1 = 0; n1 < std::cin.gcount(); n1++) {
			#ifdef VERBOSE
			std::cerr << " " << (int)((unsigned char)buffer[n1]) << "->" << (unsigned int)ct[(int)((unsigned char)buffer[n1])];
			#endif

			// transform
			if ((int)((unsigned char)buffer[n1]) < ctSize)
				buffer[n1] = ct[(int)((unsigned char)buffer[n1])];
			#ifdef VERBOSE
			else
				srd::cerr << "!";
			#endif
		}

		buffer[std::cin.gcount()] = 0;
		std::cout << buffer;
	}
}
